package WebGUI::i18n::English::Macro_AssetProxy;
use strict;

our $I18N = {

    'invalid url' => {
        message     => q|AssetProxy: Invalid Asset URL or assetId|,
        lastUpdated => 1262117594,
    },

    'asset in trash' => {
        message     => q|AssetProxy: Asset in trash|,
        lastUpdated => 1221160383,
    },

    'asset in clipboard' => {
        message     => q|AssetProxy: Asset in clipboard|,
        lastUpdated => 1221160383,
    },

};

1;
